#!/usr/bin/env bash
# this script and the README.txt files are public domain
# please pipe complaints to /dev/null
set -e
if [ ! -f ./rawgdi/*.gdi ]; then
	echo "no gdi file found in ./rawgdi/"
	exit 1
fi
numdcp="$(ls *.dcp 2>/dev/null | wc -l)"
if [ ! $numdcp -eq 1 ]; then
	echo "you must have exactly one .dcp (case-sensitive) file in this directory"
	exit 1
fi
#
if [ ! -f ./GDIbuilder/buildgdi/bin/Debug/buildgdi.exe ]; then
	echo compiling gdibuilder
	cd ./GDIbuilder/buildgdi/
	xbuild
	cd ../../
fi
#
echo Extracting original gdi
pythonexename="python"
pythonver="$(python -V 2>&1 | head -c 8)"
if [ ! "$pythonver" = "Python 2" ]; then
	pythonexename="python2"
fi
$pythonexename ./gditools_20150714/gditools.py -b IP.BIN --extract-all -o /tmp/clean-gdi-contents -i ./rawgdi/*.gdi
#################
OUTPUTDIRPATH="/tmp/patchedgame"
rm -rf $OUTPUTDIRPATH
#if [ ! -d "$OUTPUTDIRPATH" ]; then
	echo copying base rom to $OUTPUTDIRPATH
	cp -rL ./rawgdi "$OUTPUTDIRPATH"
#fi
###############

echo extracting patch
rm -rf ./extractedpatch
mkdir ./extractedpatch
cd ./extractedpatch
unzip ../*.dcp
cd ..

echo applying xdelta
xdelta3 -d -s /tmp/clean-gdi-contents/data/1ST_READ.BIN ./extractedpatch/1ST_READ.BIN.xdelta ./extractedpatch/1ST_READ.BIN
rm ./extractedpatch/1ST_READ.BIN.xdelta

echo making modified rom
mono ./GDIbuilder/buildgdi/bin/Debug/buildgdi.exe -data /tmp/clean-gdi-contents/data -patchdata ./extractedpatch/ -ip /tmp/clean-gdi-contents/IP.BIN -output "$OUTPUTDIRPATH" \
	 -cdda "$OUTPUTDIRPATH"/track04.raw \
	 "$OUTPUTDIRPATH"/track05.raw \
	 "$OUTPUTDIRPATH"/track06.raw \
	 "$OUTPUTDIRPATH"/track07.raw \
	 "$OUTPUTDIRPATH"/track08.raw \
	 "$OUTPUTDIRPATH"/track09.raw \
	 "$OUTPUTDIRPATH"/track10.raw \
	 "$OUTPUTDIRPATH"/track11.raw \
	 "$OUTPUTDIRPATH"/track12.raw \
	 "$OUTPUTDIRPATH"/track13.raw \
	 "$OUTPUTDIRPATH"/track14.raw \
	 "$OUTPUTDIRPATH"/track15.raw \
	 "$OUTPUTDIRPATH"/track16.raw \
	 "$OUTPUTDIRPATH"/track17.raw \
	 "$OUTPUTDIRPATH"/track18.raw \
	 "$OUTPUTDIRPATH"/track19.raw \
	 "$OUTPUTDIRPATH"/track20.raw \
	 "$OUTPUTDIRPATH"/track21.raw \
	 "$OUTPUTDIRPATH"/track22.raw \
	 "$OUTPUTDIRPATH"/track23.raw \
	 "$OUTPUTDIRPATH"/track24.raw \
	 "$OUTPUTDIRPATH"/track25.raw \
	 "$OUTPUTDIRPATH"/track26.raw \
	 -gdi "$OUTPUTDIRPATH"/*.gdi
########
rm -rf ./extractedpatch /tmp/clean-gdi-contents
echo patched game is at $OUTPUTDIRPATH
